@@ -1,4 +1,4 @@
-#!/usr/bin/python2.2
+#!/usr/bin/env python
 
 #        +-----------------------------------------------------------------------------+
 #        | GPL                                                                         |
@@ -20,7 +20,6 @@
 #        | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. |
 #        +-----------------------------------------------------------------------------+
 
-
 import sys
 import pygtk
 pygtk.require('2.0')
@@ -30,52 +29,64 @@ import gnome.applet
 import gnome.ui
 import os.path
 import re
+import gobject
 import pycentrino_globals as pglobals
 
-class pycentrino:
+# the class inherits from gnome.applet.Applet and we'll create it as a gobject (see __init__())
+class pycentrinoApplet(gnome.applet.Applet):
         
-    def cleanup(self,event,widget):
+    def cleanup(self,event):
         del self.applet
-
-    # callback para llamada cada 1 segundo 
+    
+    # this callback is for update the applet from system info every 1 second
     def timeout_callback(self,event):
-        
-        # si queremos parar la funcion de timeout debemos devolver 0 (en caso de que no haya soporte acpi)
-        if self.lack_p_acpi and self.lack_t_acpi:
-            return 0
-        else:
-            info = self.read_proc_info()
-            self.tooltip_text = info[0] + " " + info[1]
-            self.tooltips.set_tip (self.ev_box, self.tooltip_text)
-            
-            if info[0] is "":
-                self.tooltip_text = str(100.0 - float(self.active_t_state*(100/self.throttling_states))) + "%"
-                self.prog.set_text(self.tooltip_text)
-                self.tooltips.set_tip(self.ev_box, self.tooltip_text)
-                self.prog.set_fraction(float(self.throttling_states-self.active_t_state)/float(self.throttling_states))
-            else:
-                self.tooltip_text = (info[0]+" "+info[1])
-                self.tooltips.set_tip(self.ev_box,self.tooltip_text)
-            return 1
+        return 0
 
-    # callback para las signals de entrada y salida en el ev_box, actualizar el valor del tooltip
+    # this callback is for the entry signal at the event boxes, to update the tooltip value
     def update_info(self,widget,event):
         info = self.read_proc_info();
-        self.tooltips.set_tip(self.ev_box, info[0] + " " + info[1]);
-                    
-    # callback para crear el menu contextual
+        self.tooltips.set_tip(self.box, info[0] + " " + info[1]);
+
+    def change_orientation(self,arg1,data):
+        self.orientation = self.applet.get_orient()
+        # first remove the children of the current box
+        for i in range(len(self.numbers)):
+            self.box.remove(self.numbers[i])
+
+        # now remove the box itself
+        self.big_evbox.remove(self.box)
+
+        # time to create the new box
+        if self.orientation == gnome.applet.ORIENT_UP or self.orientation == gnome.applet.ORIENT_DOWN:
+            self.box = gtk.HBox()
+        else:
+            self.box = gtk.VBox()
+
+        # and now fill it with the numbers
+        for i in range(len(self.numbers)):
+            self.box.pack_start(self.numbers[i])
+
+        # final steps
+        self.big_evbox.add(self.box)
+        self.box.show()
+
+    # this callback is to create the context menu
     def button_press(self,widget,event):
         if event.type == gtk.gdk.BUTTON_PRESS and event.button == 3:
             self.create_menu()
+            
     
+    # and this one to show the about box   
     def about_info(self,event,data=None):
-        about = gnome.ui.About("CPU performance stats applet","0.1","GPL","Applet to check throttling and performance states",["Arturo Gonzalez"],["Arturo Gonzalez"],"Arturo Gonzalez",self.logo_pixbuf)
+        about = gnome.ui.About("CPU performance stats applet","0.2","GPL","GNOME Applet to check throttling CPU states",["Arturo Gonzalez <arturogf@ugr.es>"],\
+                               ["Arturo Gonzalez <arturogf@ugr.es>"],"Arturo Gonzalez <arturogf@ugr.es>",self.logo_pixbuf)
         about.show()
-    
+
+    # the preferences one
     def properties(self,event,data=None):
         self.preferences.show()
     
-    # funcion de actualizacion de la informacion extraida de /proc/acpi
+    # this function update the info extracted from /proc/acpi
     def read_proc_info(self):
 
         # throttling support
@@ -122,7 +133,7 @@ class pycentrino:
         else:
             self.lack_p_acpi = 1
 
-        #devolvemos "" si va bien o mensaje si falta algo
+        # we return a tuple. In case there is no support, return a error string to be shown
         if self.lack_t_acpi and self.lack_p_acpi:
             return ("lack of throttling acpi support","lack of power acpi support")
         else:
@@ -135,7 +146,7 @@ class pycentrino:
                     return("","")
 
 
-    # callback para la creacion del menu contextual boton derechso
+    # this callback is to create a context menu with the second button
     def create_menu(self):
         self.applet.setup_menu(self.propxml,self.verbs,None)
 
@@ -145,6 +156,7 @@ class pycentrino:
         widget.hide()
         return gtk.TRUE
 
+    # callbacks for the togglebuttons on the preferences window. It just prints out the info of the checks vector
     def on_checkbutton1_toggled(self,widget):
         self.checks[0] = widget.get_active()
         print self.checks
@@ -161,8 +173,13 @@ class pycentrino:
         self.checks[4] = widget.get_active()
         print self.checks
 
+    # the __init__ method
     def __init__(self,applet,iid):
 
+        # do it a gobject. Look at Lorenzo Gil tutorial about sub-classing gobject in Python
+        self.__gobject_init__()
+
+        # instance variable section
         self.timeout_interval = 1000        
         self.throttling_states = 0
         self.active_t_state = "T0"
@@ -170,11 +187,11 @@ class pycentrino:
         self.actual_cpu_state = "C1"
         self.lack_t_acpi = 0
         self.lack_p_acpi = 0
-        self.dict = {}
-        self.bar_bg_color = "#C5D2C8"
-        self.bar_fg_color = "#C5D2C8"
+        self.prueba = {}
         self.tooltip_text = ""
         self.checks = [0,0,0,0,0]
+        self.orientation = gnome.applet.ORIENT_UP
+        self.numbers = []
 
         self.propxml="""
         <popup name="button3">
@@ -186,48 +203,68 @@ class pycentrino:
         self.verbs = [ ( "Props", self.properties ),
                        ( "About", self.about_info )  
 	             ]
-            
+
+        # initialize gnome application and set up all the gnome internals
         gnome.init(pglobals.name, pglobals.version)
 
+        # create the logo from file centrino.gif
         self.logo = gtk.Image()
         self.logo.set_from_file(os.path.join(pglobals.image_dir,'centrino.gif'))
         self.logo_pixbuf = self.logo.get_pixbuf()
+
+        # fill the numbers vector with images of numbers
+        for i in range(10):
+            self.numbers.append(gtk.Image())
+            self.numbers[i].set_from_file(os.path.join(pglobals.image_dir,'green_led_%d.gif' % i))
+
+        # create the applet and the widgets
         self.applet = applet
-
         self.tooltips = gtk.Tooltips()
-        self.hbox = gtk.HBox()
-        applet.add(self.hbox)
+        self.big_evbox = gtk.EventBox()
+        self.big_evbox.connect("button-press-event",self.button_press)
+        self.big_evbox.connect("enter-notify-event", self.update_info)
+        self.box = None
 
-        self.ev_box = gtk.EventBox()
-        self.ev_box.connect("button-press-event",self.button_press)
-        self.ev_box.connect("enter-notify-event", self.update_info)
-        self.hbox.add(self.ev_box)
+        self.orientation = applet.get_orient()
 
-        self.prog = gtk.ProgressBar()
+        # if we have an horizontal panel if self.orientation ==
+        if self.orientation == gnome.applet.ORIENT_UP or self.orientation == gnome.applet.ORIENT_DOWN:
+            self.box = gtk.HBox()
+        # if it's a vertical one
+        else:
+            self.box = gtk.VBox()
 
-        self.prog.modify_bg(gtk.STATE_NORMAL, gtk.gdk.color_parse(self.bar_bg_color))
-        self.prog.modify_fg(gtk.STATE_NORMAL, gtk.gdk.color_parse("white"))
-        self.prog.modify_bg(gtk.STATE_ACTIVE, gtk.gdk.color_parse(self.bar_bg_color))
-        self.prog.modify_fg(gtk.STATE_ACTIVE, gtk.gdk.color_parse("white"))
-        self.prog.modify_bg(gtk.STATE_PRELIGHT, gtk.gdk.color_parse(self.bar_bg_color))
-        self.prog.modify_fg(gtk.STATE_PRELIGHT, gtk.gdk.color_parse("white"))
-        self.ev_box.add(self.prog)
+        # now add the numbers to the box
+        for i in range(len(self.numbers)):
+            self.box.pack_start(self.numbers[i])
 
+        self.big_evbox.add(self.box)
+
+        self.applet.add(self.big_evbox)        
+
+        # update info from filesystem
         gtk.timeout_add(self.timeout_interval,self.timeout_callback, self)
+        
+        # connect some signals to the applet
+        self.applet.connect("change-orient",self.change_orientation)
+        self.applet.connect("destroy",self.cleanup)
+        self.applet.show_all()
 
-        applet.connect("destroy",self.cleanup,None)
-        applet.show_all()
-
+        # read the .glade file to construct the properties window
         wT = gtk.glade.XML(os.path.join(pglobals.glade_dir, "pycentrino.glade"))
         preferencesDialog = wT.get_widget('properties')
         self.preferences = preferencesDialog
         wT.signal_autoconnect(self)
 
+gobject.type_register(pycentrinoApplet)
+
+# bonobo factory of pycentrinoApplets
 def pycentrino_applet_factory(applet, iid):
-    pycentrino(applet,iid)
+    pycentrinoApplet(applet,iid)
     return gtk.TRUE
 
-if len(sys.argv) == 2 and sys.argv[1] == "run-in-window":
+# run it in a gtk window
+if len(sys.argv) > 1 and sys.argv[1] == "run-in-window":
     main_window = gtk.Window(gtk.WINDOW_TOPLEVEL)
     main_window.set_title("Pycentrino Applet")
     main_window.connect("destroy", gtk.mainquit) 
@@ -240,7 +277,7 @@ if len(sys.argv) == 2 and sys.argv[1] == "run-in-window":
 
 if __name__ == '__main__':
     gnome.applet.bonobo_factory("OAFIID:GNOME_PycentrinoApplet_Factory",
-                                gnome.applet.Applet.__gtype__, 
+                                pycentrinoApplet.__gtype__, 
                                 "hello", "0", pycentrino_applet_factory)
 
     
